@@ -19,9 +19,9 @@
 import os
 import sys
 
-__version__ = "1.0.2"
+IS_WIN = os.name == "nt"
+IS_PYODIDE = "pyodide" in sys.modules
+IS_WASI = sys.platform == "wasi"
+IS_WASM = IS_PYODIDE or IS_WASI
 
-IS_WIN = os.name == 'nt'
-IS_PYODIDE = 'pyodide' in sys.modules
-
-pygls = 'pygls'
+pygls = "pygls"
